##########################################################################
#
# FILE:
#       updui.pm
# 
# DESCRIPTION: 
#       Contains the funtion that will dislpay the 
#		instance spec. and will prompt the user for
#		a filename and propriety information regarding
#		the instance spec.
#
# AUTHORS:
#       Marc Mengel
#       Lars Rasmussen
#       Margaret Votava
#       Don Walsh
#
#       Fermilab Computing Division
#       Batavia, Il 60510, U.S.A.                                              
#
# MODIFICATIONS:
#       dd-mmm-yyyy, NN, first
#
##########################################################################

package updui;

require Exporter;

@ISA = qw(Exporter);

##########################################################################
# Exported Functions
#
##########################################################################

@EXPORT = qw ( updui_prompt_propriety );

##########################################################################
# What to use
#
##########################################################################

use strict;
use updxfr;
use upderr;

##########################################################################

#-------------------------------------------------------------------------
# updui_prompt_propriety($instance_spec, $prop_info, $filename)
#
# Prompt the user to enter a 'filename' and special
# propriety product fretch information 'prop_info'
# needed for 'instance spec'.
#
# Input : reference \%instance_spec,
# Output: reference \$prop_info,
# Output: reference \$filename.
# Return: scalar status_code
#

sub updui_prompt_propriety {
	my ($inst_spec,
		$prop_info,
		$filename) = @_;

	my $status = 1;
	my $spec = "\0";
	my $Pstr = '0';
	my $yorn;


	$| = 1;
	print "Product ",
		$inst_spec->{product}, " " , 
		$inst_spec->{version}, " " , 
		$inst_spec->{flavor}, " ",
		"is a proprietary product.\n";
	print "Before it can be installed, you need to obtain a group name and password for\n";
	print "it by sending a proprietary products request form to compdiv\@fnal.gov\n";
	print "\n";
	print "Have you obtained a group name and password? ";
	chomp( $yorn = <STDIN> );

        if ($yorn =~ /\Ay.*/i ) {
 	    
	    print "\n";
	    print "Enter Group Name: ";
	    chomp($prop_info->{'group_name'} = <STDIN>);
	    
	    print "Enter Group Pass word: ";
	    chomp($prop_info->{'pass_word'} = <STDIN>);
	    
	    # no longer needed with new proprietary structure -- mengel
	    # print "Enter Filename: ";
	    # chomp(${$filename} = <STDIN>);

	} else {
	    print "Do you need a proprietary product request form? ";
	    chomp( $yorn = <STDIN> );
            if ($yorn =~ /\Ay.*/i ) {
		updxfr_file("fnkits.fnal.gov", "/ftp/products/proprietarylist", "proprietary.form", "$::ENV{HOME}/proprietary.form", {});
		upderr_get(); upderr_clear();
		exit(0);
	    }

	    $status = 0;

	}

	return $status;
}

if ( $0 =~ /updui.pm\Z/ ) {
    my $inst_spec = { product => 'fred', version => 'v0_0', flavor => "IRIX"};
    updui_prompt_propriety( $inst_spec, {}, "foo" );
}

1;

__END__

=head1 NAME

upderr - blah blah

=head1 SYNOPSIS

<use it this way>

=head1 DESCRIPTION

<description>

=head1 BUGS

<bugs>

=cut

